@@ -40,7 +40,6 @@ namespace kt
 	class ViewSelectionModel;
 	class ViewDelegate;
 	class Group;
-	class TorrentInterface;
 
 	class View : public QTreeView
 	{
@@ -78,12 +77,9 @@ namespace kt
 
 		/// Get the current group
 		const Group* getGroup() const {return group;}
-
-		/// Save the view's state
-		void saveState(KSharedConfigPtr cfg);
-
-		/// Load the view's state
-		void loadState(KSharedConfigPtr cfg);
+		
+		/// Restore the view state
+		void restoreState(const QByteArray & state);
 
 		/// Get the current torrent
 		bt::TorrentInterface* getCurrentTorrent();
@@ -102,7 +98,11 @@ namespace kt
 
 		/// Extend a widget
 		void extend(bt::TorrentInterface* tc, Extender* widget, bool close_similar);
+		
+		/// Get the default state
+		const QByteArray & defaultState() const {return default_state;}
 
+		virtual void keyPressEvent(QKeyEvent* event);
 
 	public slots:
 		/// Set the filter string
@@ -137,9 +137,9 @@ namespace kt
 		void onSelectionChanged(const QItemSelection & selected, const QItemSelection & deselected);
 		void onDoubleClicked(const QModelIndex & index);
 		void onCurrentGroupChanged(kt::Group* g);
-		void onGroupRenamed(kt::Group* g);
-		void onGroupRemoved(kt::Group* g);
-		void onGroupAdded(kt::Group* g);
+		void onGroupRenamed(Group* g);
+		void onGroupRemoved(Group* g);
+		void onGroupAdded(Group* g);
 
 		/// An item in the groups menu was triggered
 		void addToGroupItemTriggered();
@@ -175,6 +175,7 @@ namespace kt
 		ViewSelectionModel* selection_model;
 		ViewDelegate* delegate;
 		QMap<bt::TorrentInterface*, Extender*> data_scan_extenders;
+		QByteArray default_state;
 
 		// actions for the view menu
 		KAction* start_torrent;
