@@ -32,26 +32,26 @@
 
 namespace kt
 {
-	
-	
+
+
 	//////////////////////////
-	
+
 	ExtenderBox::ExtenderBox(QWidget* widget): QWidget(widget)
 	{
 		layout = new QVBoxLayout(this);
 	}
-	
+
 	ExtenderBox::~ExtenderBox()
 	{
 		clear();
 	}
-	
+
 	void ExtenderBox::add(Extender* ext)
 	{
 		layout->addWidget(ext);
 		extenders.append(ext);
 	}
-	
+
 	void ExtenderBox::remove(Extender* ext)
 	{
 		layout->removeWidget(ext);
@@ -60,33 +60,49 @@ namespace kt
 		ext->deleteLater();
 	}
 	
+	void ExtenderBox::removeSimilar(Extender* ext)
+	{
+		for (QList<Extender*>::iterator i = extenders.begin(); i != extenders.end(); )
+		{
+			if (ext->similar(*i))
+			{
+				(*i)->hide();
+				(*i)->deleteLater();
+				i = extenders.erase(i);
+			}
+			else
+				i++;
+		}
+	}
+
+
 	void ExtenderBox::clear()
 	{
-		foreach (Extender* ext,extenders)
+		foreach(Extender* ext, extenders)
 		{
 			ext->hide();
 			ext->deleteLater();
 		}
-		
+
 		extenders.clear();
 	}
 
 
 	//////////////////////////
-	
-	ViewDelegate::ViewDelegate(Core* core,ViewModel* model,View* parent): QStyledItemDelegate(parent),model(model)
+
+	ViewDelegate::ViewDelegate(Core* core, ViewModel* model, View* parent): QStyledItemDelegate(parent), model(model)
 	{
-		connect(core,SIGNAL(torrentRemoved(bt::TorrentInterface*)),
-				this,SLOT(torrentRemoved(bt::TorrentInterface*)));
+		connect(core, SIGNAL(torrentRemoved(bt::TorrentInterface*)),
+		        this, SLOT(torrentRemoved(bt::TorrentInterface*)));
 	}
 
 	ViewDelegate::~ViewDelegate()
 	{
 		contractAll();
 	}
-	
-	
-	void ViewDelegate::extend(bt::TorrentInterface* tc, Extender* widget)
+
+
+	void ViewDelegate::extend(bt::TorrentInterface* tc, kt::Extender* widget, bool close_similar)
 	{
 		ExtenderBox* ext = 0;
 		ExtItr itr = extenders.find(tc);
@@ -94,22 +110,25 @@ namespace kt
 		{
 			QAbstractItemView *aiv = qobject_cast<QAbstractItemView *>(parent());
 			ext = new ExtenderBox(aiv->viewport());
-			extenders.insert(tc,ext);
+			extenders.insert(tc, ext);
 		}
 		else
 		{
 			ext = itr.value();
 		}
 		
+		if (close_similar)
+			ext->removeSimilar(widget);
+
 		ext->add(widget);
 		widget->setParent(ext);
 		widget->show();
-		
+
 		scheduleUpdateViewLayout();
-		connect(widget,SIGNAL(closeRequest(Extender*)),this,SLOT(closeRequested(Extender*)));
-		connect(widget,SIGNAL(resized(Extender*)),this,SLOT(resized(Extender*)));
+		connect(widget, SIGNAL(closeRequest(Extender*)), this, SLOT(closeRequested(Extender*)));
+		connect(widget, SIGNAL(resized(Extender*)), this, SLOT(resized(Extender*)));
 	}
-	
+
 	void ViewDelegate::closeExtenders(bt::TorrentInterface* tc)
 	{
 		ExtItr itr = extenders.find(tc);
@@ -121,10 +140,10 @@ namespace kt
 			ext->deleteLater();
 			extenders.erase(itr);
 		}
-		
+
 		scheduleUpdateViewLayout();
 	}
-	
+
 	void ViewDelegate::closeExtender(bt::TorrentInterface* tc, Extender* ext)
 	{
 		ExtItr itr = extenders.find(tc);
@@ -139,105 +158,105 @@ namespace kt
 				extenders.erase(itr);
 			}
 		}
-		
+
 		scheduleUpdateViewLayout();
 	}
-	
+
 	void ViewDelegate::closeRequested(Extender* ext)
 	{
-		closeExtender(ext->torrent(),ext);
+		closeExtender(ext->torrent(), ext);
 	}
 
 	void ViewDelegate::torrentRemoved(bt::TorrentInterface* tc)
 	{
 		closeExtenders(tc);
 	}
-	
+
 	void ViewDelegate::resized(Extender* ext)
 	{
 		Q_UNUSED(ext);
 		scheduleUpdateViewLayout();
 	}
 
-	
+
 	QSize ViewDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
 	{
 		QSize ret;
-		
-		if (!extenders.isEmpty()) 
+
+		if (!extenders.isEmpty())
 			ret = maybeExtendedSize(option, index);
 		else
 			ret = QStyledItemDelegate::sizeHint(option, index);
-		
+
 		return ret;
 	}
-	
+
 	QSize ViewDelegate::maybeExtendedSize(const QStyleOptionViewItem &option, const QModelIndex &index) const
 	{
 		bt::TorrentInterface* tc = model->torrentFromIndex(index);
 		QSize size(QStyledItemDelegate::sizeHint(option, index));
 		if (!tc)
 			return size;
-		
+
 		ExtCItr itr = extenders.find(tc);
 		const QWidget* ext = itr == extenders.end() ? 0 : itr.value();
 		if (!ext)
 			return size;
-		
+
 		//add extender height to maximum height of any column in our row
 		int item_height = size.height();
 		int row = index.row();
 		int this_column = index.column();
-		
+
 		//this is quite slow, but Qt is smart about when to call sizeHint().
-		for (int column = 0; model->columnCount() < column; column++) 
+		for (int column = 0; model->columnCount() < column; column++)
 		{
-			if (column == this_column) 
+			if (column == this_column)
 				continue;
-			
+
 			QModelIndex neighborIndex(index.sibling(row, column));
-			if (neighborIndex.isValid()) 
+			if (neighborIndex.isValid())
 				item_height = qMax(item_height, QStyledItemDelegate::sizeHint(option, neighborIndex).height());
 		}
-		
+
 		//we only want to reserve vertical space, the horizontal extender layout is our private business.
 		size.rheight() = item_height + ext->sizeHint().height();
 		return size;
 	}
 
-	
+
 	void ViewDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
 	{
 		QStyleOptionViewItemV4 indicatorOption(option);
 		initStyleOption(&indicatorOption, index);
-		if (index.column() == 0) 
+		if (index.column() == 0)
 			indicatorOption.viewItemPosition = QStyleOptionViewItemV4::Beginning;
-		else if (index.column() == index.model()->columnCount() - 1) 
+		else if (index.column() == index.model()->columnCount() - 1)
 			indicatorOption.viewItemPosition = QStyleOptionViewItemV4::End;
-		else 
+		else
 			indicatorOption.viewItemPosition = QStyleOptionViewItemV4::Middle;
-		
+
 		QStyleOptionViewItemV4 itemOption(option);
 		initStyleOption(&itemOption, index);
-		if (index.column() == 0) 
+		if (index.column() == 0)
 			itemOption.viewItemPosition = QStyleOptionViewItemV4::Beginning;
 		else if (index.column() == index.model()->columnCount() - 1)
 			itemOption.viewItemPosition = QStyleOptionViewItemV4::End;
-		else 
+		else
 			itemOption.viewItemPosition = QStyleOptionViewItemV4::Middle;
-		
-		
+
+
 		bt::TorrentInterface* tc = model->torrentFromIndex(index);
 		if (!tc || !extenders.contains(tc))
 		{
 			normalPaint(painter, itemOption, index);
 			return;
 		}
-		
+
 		QWidget* extender = extenders[tc];
 		int extenderHeight = extender->sizeHint().height();
-		
-		
+
+
 		//an extender is present - make two rectangles: one to paint the original item, one for the extender
 		QStyleOptionViewItemV4 extOption(option);
 		initStyleOption(&extOption, index);
@@ -246,29 +265,29 @@ namespace kt
 		//if we show it before, it will briefly flash in the wrong location.
 		//the downside is, of course, that an api user effectively can't hide it.
 		extender->show();
-		
+
 		indicatorOption.rect.setHeight(option.rect.height() - extenderHeight);
 		itemOption.rect.setHeight(option.rect.height() - extenderHeight);
 		//tricky:make sure that the modified options' rect really has the
 		//same height as the unchanged option.rect if no extender is present
 		//(seems to work OK)
-		
+
 		normalPaint(painter, itemOption, index);
 	}
-	
-	
-	void ViewDelegate::updateEditorGeometry(QWidget* editor,const QStyleOptionViewItem& option,const QModelIndex& index) const
+
+
+	void ViewDelegate::updateEditorGeometry(QWidget* editor, const QStyleOptionViewItem& option, const QModelIndex& index) const
 	{
 		bt::TorrentInterface* tc = model->torrentFromIndex(index);
 		if (!tc || !extenders.contains(tc))
 		{
-			QStyledItemDelegate::updateEditorGeometry(editor,option,index);
+			QStyledItemDelegate::updateEditorGeometry(editor, option, index);
 		}
 		else
 		{
 			QWidget* extender = extenders[tc];
 			int extenderHeight = extender->sizeHint().height();
-			
+
 			QStyleOptionViewItemV4 itemOption(option);
 			initStyleOption(&itemOption, index);
 			itemOption.rect.setHeight(option.rect.height() - extenderHeight);
@@ -276,25 +295,25 @@ namespace kt
 		}
 	}
 
-	
+
 	QRect ViewDelegate::extenderRect(QWidget *extender, const QStyleOptionViewItem &option, const QModelIndex &index) const
 	{
 		QRect rect(option.rect);
 		rect.setTop(rect.bottom() + 1 - extender->sizeHint().height());
-		
+
 		rect.setLeft(0);
-		if (QTreeView *tv = qobject_cast<QTreeView *>(parent())) 
+		if (QTreeView *tv = qobject_cast<QTreeView *>(parent()))
 		{
 			int steps = 0;
-			for (QModelIndex idx(index.parent()); idx.isValid(); idx = idx.parent()) 
+			for (QModelIndex idx(index.parent()); idx.isValid(); idx = idx.parent())
 				steps++;
-			
-			if (tv->rootIsDecorated()) 
+
+			if (tv->rootIsDecorated())
 				steps++;
-			
+
 			rect.setLeft(steps * tv->indentation());
 		}
-		
+
 		QAbstractScrollArea *container = qobject_cast<QAbstractScrollArea *>(parent());
 		rect.setRight(container->viewport()->width() - 1);
 		return rect;
@@ -305,7 +324,7 @@ namespace kt
 	{
 		QAbstractItemView *aiv = qobject_cast<QAbstractItemView *>(parent());
 		//prevent crashes during destruction of the view
-		if (aiv) 
+		if (aiv)
 		{
 			//dirty hack to call aiv's protected scheduleDelayedItemsLayout()
 			aiv->setRootIndex(aiv->rootIndex());
@@ -323,14 +342,14 @@ namespace kt
 		}
 		extenders.clear();
 	}
-	
-	
+
+
 	bool ViewDelegate::extended(bt::TorrentInterface* tc) const
 	{
 		return extenders.contains(tc);
 	}
-	
-	
+
+
 	void ViewDelegate::hideExtender(bt::TorrentInterface* tc)
 	{
 		ExtItr i = extenders.find(tc);
@@ -338,11 +357,11 @@ namespace kt
 			i.value()->hide();
 	}
 
-	
+
 	void ViewDelegate::paintProgressBar(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
 	{
 		double progress = index.data().toDouble();
-		
+
 		QStyleOptionProgressBar progressBarOption;
 		progressBarOption.palette = option.palette;
 		progressBarOption.state = option.state;
@@ -350,20 +369,20 @@ namespace kt
 		progressBarOption.minimum = 0;
 		progressBarOption.maximum = 100;
 		progressBarOption.progress = (int)progress;
-		progressBarOption.text = KGlobal::locale()->formatNumber(progress,2) + "%";
+		progressBarOption.text = KGlobal::locale()->formatNumber(progress, 2) + "%";
 		progressBarOption.textVisible = true;
 		progressBarOption.direction = option.direction;
-		
+
 		KApplication::style()->drawControl(QStyle::CE_ProgressBar, &progressBarOption, painter);
 	}
 
-	
+
 	void ViewDelegate::normalPaint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
 	{
 		if (index.column() == ViewModel::PERCENTAGE)
-			paintProgressBar(painter,option,index);
+			paintProgressBar(painter, option, index);
 		else
-			QStyledItemDelegate::paint(painter,option,index);
+			QStyledItemDelegate::paint(painter, option, index);
 	}
 
 }
