@@ -21,6 +21,9 @@
 #include "applet.h"
 #include <QFile>
 #include <QGraphicsLinearLayout>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+#include <QDBusMessage>
 #include <KConfigDialog>
 #include <KLocale>
 #include <KRun>
@@ -31,12 +34,11 @@
 #include <Plasma/IconWidget>
 #endif
 #include <Plasma/Label>
-#include <taskmanager/taskmanager.h>
-#include <taskmanager/task.h>
 #include <util/functions.h>
 #include "chunkbar.h"
 #include "fadingnavigationwidget.h"
 
+
 using namespace bt;
 
 namespace ktplasma
@@ -174,7 +176,8 @@ namespace ktplasma
 		}
 	}
 
-	void Applet::updateNavigation() {
+	void Applet::updateNavigation() 
+	{
 		navigation->setEnabled(connected_to_app && !sources.empty()
 			&& (sources.count() > 1 || !sources.contains(current_source)));
 	}
@@ -193,12 +196,14 @@ namespace ktplasma
 		}
 	}
 	
-	void Applet::updateSources() {
+	void Applet::updateSources() 
+	{
 		sources = engine->sources();
 		sources.removeOne("core");
 	}
 
-	void Applet::setSource(QString source) {
+	void Applet::setSource(QString source) 
+	{
 		if (!current_source.isEmpty())
 			engine->disconnectSource(current_source,this);
 		clearData();
@@ -340,20 +345,39 @@ namespace ktplasma
 
 	void Applet::iconClicked()
 	{
-		TaskManager::TaskDict tasks = TaskManager::TaskManager::self()->tasks();
-		for (TaskManager::TaskDict::iterator i = tasks.begin();i != tasks.end();i ++)
+		QDBusConnection session_bus = QDBusConnection::sessionBus();
+		QDBusConnectionInterface* dbus_service = session_bus.interface();
+		if (!session_bus.isConnected() || !dbus_service || !dbus_service->isServiceRegistered("org.ktorrent.ktorrent"))
 		{
-			if (i.value()->className() == "ktorrent")
-			{
-				KWindowSystem::activateWindow(i.key());
-				return;
-			}
+			// can't find the window, try launching it
+			KUrl::List empty;
+			KRun::run("ktorrent", empty, 0);
+		}
+		else
+		{
+			QDBusMessage msg = QDBusMessage::createMethodCall("org.ktorrent.ktorrent", "/ktorrent/MainWindow_1", "org.kde.KMainWindow", "winId");
+			QDBusPendingCall call = session_bus.asyncCall(msg, 5000);
+			QDBusPendingCallWatcher* watcher = new QDBusPendingCallWatcher(call ,this);
+			connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher*)), this, SLOT(dbusCallFinished(QDBusPendingCallWatcher*)));
 		}
-
-		// can't find the window, try launching it
-		KUrl::List empty;
-		KRun::run("ktorrent", empty, 0);
 	}
+	
+	void Applet::dbusCallFinished(QDBusPendingCallWatcher* self)
+	{
+		if (self->isError())
+		{
+			// call failed, try launching it
+			KUrl::List empty;
+			KRun::run("ktorrent", empty, 0);
+		}
+		else
+		{
+			QDBusPendingReply<qlonglong> reply = *self;
+			KWindowSystem::activateWindow(reply.value());		
+		}
+		self->deleteLater();
+	}
+
 
 	void Applet::clearData()
 	{		
