@@ -23,11 +23,7 @@
 
 #include "ui_trackerview.h"
 #include <QSortFilterProxyModel>
-
-namespace bt
-{
-	class TorrentInterface;
-}
+#include <interfaces/torrentinterface.h>
 
 namespace kt
 {
@@ -42,28 +38,30 @@ namespace kt
 	public:
 		TrackerView(QWidget *parent);
 		virtual ~TrackerView();
-			
+
 		void update();
 		void changeTC(bt::TorrentInterface* ti);
 		void saveState(KSharedConfigPtr cfg);
 		void loadState(KSharedConfigPtr cfg);
-			
+
 	public slots:
 		virtual void updateClicked();
 		virtual void restoreClicked();
 		virtual void changeClicked();
 		virtual void removeClicked();
-		virtual void addClicked();        
+		virtual void addClicked();
 		virtual void scrapeClicked();
-		void currentChanged(const QModelIndex & current,const QModelIndex & previous);
-			
+		void currentChanged(const QModelIndex & current, const QModelIndex & previous);
+
 	private:
 		void torrentChanged(bt::TorrentInterface* ti);
-			
+
 	private:
-		bt::TorrentInterface* tc;
+		bt::TorrentInterface::WPtr tc;
 		TrackerModel* model;
 		QSortFilterProxyModel* proxy_model;
+		QStringList tracker_hints;
+		bool header_state_loaded;
 	};
 }
 #endif
