@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
+ *   Copyright (C) 2005-2007 by Joris Guisson                              *
  *   joris.guisson@gmail.com                                               *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,50 +15,46 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 #ifndef KTSEARCHPLUGIN_H
 #define KTSEARCHPLUGIN_H
 
-#include <qptrlist.h>
+#include <QList>
 #include <interfaces/plugin.h>
 #include <interfaces/guiinterface.h>
 #include "searchenginelist.h"
 
 namespace kt
 {
-	class SearchWidget;
 	class SearchPrefPage;
-	class SearchTab;
+	class SearchActivity;
 
 	/**
 	@author Joris Guisson
 	*/
-	class SearchPlugin : public Plugin, public kt::CloseTabListener
+	class SearchPlugin : public Plugin
 	{
 		Q_OBJECT
 	public:
-		SearchPlugin(QObject* parent, const char* name, const QStringList& args);
+		SearchPlugin(QObject* parent, const QStringList& args);
 		virtual ~SearchPlugin();
 
 		virtual void load();
 		virtual void unload();
 		virtual bool versionCheck(const QString& version) const;
 		
-		void preferencesUpdated();
+		SearchEngineList* getSearchEngineList() const {return engines;}
+		SearchActivity* getSearchActivity() const {return activity;}
 		
-		const SearchEngineList & getSearchEngineList() const {return engines;}
 	private slots:
 		void search(const QString & text,int engine,bool external);
+		void preferencesUpdated();
 		
 	private:
-		virtual void tabCloseRequest(kt::GUIInterface* gui,QWidget* tab);
-		
-	private:
+		SearchActivity* activity;
 		SearchPrefPage* pref;
-		SearchTab* tab;
-		SearchEngineList engines;
-		QPtrList<SearchWidget> searches;
+		SearchEngineList* engines;
 	};
 
 }
