@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
+ *   Copyright (C) 2005-2007 by Joris Guisson                              *
  *   joris.guisson@gmail.com                                               *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,17 +15,21 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 #ifndef KTSEARCHPLUGIN_H
 #define KTSEARCHPLUGIN_H
 
 #include <interfaces/plugin.h>
 
-namespace kt
+namespace bt
 {
 	class UPnPMCastSocket;
-	class UPnPPrefPage;
+}
+
+namespace kt
+{
+	class UPnPWidget;
 
 	/**
 	@author Joris Guisson
@@ -34,7 +38,7 @@ namespace kt
 	{
 		Q_OBJECT
 	public:
-		UPnPPlugin(QObject* parent, const char* name, const QStringList& args);
+		UPnPPlugin(QObject* parent, const QStringList& args);
 		virtual ~UPnPPlugin();
 
 		virtual void load();
@@ -42,8 +46,8 @@ namespace kt
 		virtual void shutdown(bt::WaitJob* job);
 		virtual bool versionCheck(const QString& version) const;
 	private:
-		UPnPMCastSocket* sock;
-		UPnPPrefPage* pref;
+		bt::UPnPMCastSocket* sock;
+		UPnPWidget* upnp_tab;
 	};
 
 }
