@@ -160,7 +160,7 @@ namespace kt
 			session.logged_in = true;
 			session.sessionId = rand();
 			session.last_access = QTime::currentTime();
-			Out(SYS_WEB|LOG_NOTICE) << "Webgui login succesfull ! (auth disable)" << endl;
+			Out(SYS_WEB|LOG_NOTICE) << "Webgui login successful ! (auth disable)" << endl;
 			challenge = QString();
 			return true;
 		}
@@ -191,14 +191,14 @@ namespace kt
 			return false;
 		}
 		
-		QByteArray s = (challenge + WebInterfacePluginSettings::password()).toUtf8();
+		QByteArray s = (QString(challenge + WebInterfacePluginSettings::password())).toUtf8();
 		bt::SHA1Hash hash = bt::SHA1Hash::generate((const bt::Uint8*)s.data(),s.length());
 		if (hash.toString() == challenge_hash)
 		{
 			session.logged_in = true;
 			session.sessionId=rand();
 			session.last_access=QTime::currentTime();
-			Out(SYS_WEB|LOG_NOTICE) << "Webgui login succesfull !" << endl;
+			Out(SYS_WEB|LOG_NOTICE) << "Webgui login successful !" << endl;
 			challenge = QString();
 			return true;
 		}
