@@ -40,88 +40,35 @@ namespace kt
 		: PrefPageInterface(WebInterfacePluginSettings::self(),i18n("Web Interface"),"network-server",parent)
 	{
 		setupUi(this);
+		connect(kcfg_authentication,SIGNAL(toggled(bool)),this,SLOT(authenticationToggled(bool)));
 	
 		QStringList dirList =KGlobal::dirs()->findDirs("data", "ktorrent/www");
-		QDir d(*(dirList.begin()));
-		
-		QStringList skinList = d.entryList(QDir::Dirs);
-		foreach (QString skin,skinList)
+		if (!dirList.isEmpty())
 		{
-			if (skin =="." || skin == ".." || skin == "common")
-				continue;
-			kcfg_skin->addItem(skin);
+			QDir d(*(dirList.begin()));
+			
+			QStringList skinList = d.entryList(QDir::Dirs);
+			foreach (const QString& skin,skinList)
+			{
+				if (skin =="." || skin == ".." || skin == "common")
+					continue;
+				kcfg_skin->addItem(skin);
+			}
 		}
-
-		if (WebInterfacePluginSettings::phpExecutablePath().isEmpty())
-		{
-			QString phpPath = KStandardDirs::findExe("php");
-			if(phpPath==QString::null)
-				phpPath = KStandardDirs::findExe("php-cli");
-
-			kcfg_phpExecutablePath->setUrl(phpPath);
-		}
-		
-		connect(kcfg_phpExecutablePath,SIGNAL(textChanged(const QString &)),this,SLOT(textChanged(const QString &)));
+		kcfg_username->setEnabled(WebInterfacePluginSettings::authentication());
+		kcfg_password->setEnabled(WebInterfacePluginSettings::authentication());
 	}
 	
 	WebInterfacePrefWidget::~WebInterfacePrefWidget()
 	{}
 
-	/*
-	bool WebInterfacePrefWidget::apply()
+	void WebInterfacePrefWidget::authenticationToggled(bool on)
 	{
-		if(WebInterfacePluginSettings::port()==kcfg_port->value()){
-			if(forward->isChecked())
-				bt::Globals::instance().getPortList().addNewPort(kcfg_port->value(),net::TCP,true);
-			else
-				bt::Globals::instance().getPortList().removePort(kcfg_port->value(),net::TCP);
-		}		
-		WebInterfacePluginSettings::setPort(kcfg_port->value () );
-		WebInterfacePluginSettings::setForward(forward->isChecked());
-		WebInterfacePluginSettings::setSessionTTL(sessionTTL->value () );
-		WebInterfacePluginSettings::setSkin(interfaceSkinBox->currentText());
-		WebInterfacePluginSettings::setPhpExecutablePath(phpExecutablePath->url () );
-		if(!username->text().isEmpty() && !password.isEmpty()){
-			WebInterfacePluginSettings::setUsername(username->text() );
-			KMD5 context(password);
-			WebInterfacePluginSettings::setPassword(context.hexDigest().data());
-		}
+		kcfg_username->setEnabled(on);
+		kcfg_password->setEnabled(on);
+	}
 
-		WebInterfacePluginSettings::writeConfig();
-		return true;
-	}
-*/
 	
-	
-	void WebInterfacePrefWidget::textChanged(const QString & path)
-	{
-		QFileInfo fi(path);
-		if(fi.isExecutable() && (fi.isFile() || fi.isSymLink()))
-		{
-			kled->setToolTip(i18n("%1 exists and it is executable",path));
-			kled->setColor(Qt::green);
-		}
-		else if (!fi.exists())
-		{
-			kled->setToolTip(i18n("%1 does not exist",path));
-			kled->setColor(Qt::red);
-		}
-		else if (!fi.isExecutable())
-		{
-			kled->setToolTip(i18n("%1 is not executable",path));
-			kled->setColor(Qt::red);
-		}
-		else if (fi.isDir())
-		{
-			kled->setToolTip(i18n("%1 is a directory",path));
-			kled->setColor(Qt::red);
-		}
-		else
-		{
-			kled->setToolTip(i18n("%1 is not php executable path",path));
-			kled->setColor(Qt::red);
-		}
-	}
 }
 
 #include "webinterfaceprefwidget.moc"
